==> haskell-zinza-0.2-182-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-zinza.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zinza
version:              0.2
visibility:           public
id:                   zinza-0.2-9jD5lgfRzFzEfxrjlpNboz
key:                  zinza-0.2-9jD5lgfRzFzEfxrjlpNboz
license:              GPL-2.0-or-later
copyright:            (c) 2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg.Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/zinza
synopsis:             Typed templates with jinja like syntax
description:
    Typed templates with jinja like syntax. Well-typed templates don'\''t go wrong.

category:             Text, Template
abi:                  bb272624b03df1ed5d5fe175570067a1
exposed:              True
exposed-modules:      Zinza
hidden-modules:
    Zinza.Check Zinza.Class Zinza.Errors Zinza.Expr Zinza.Generic
    Zinza.Indexing Zinza.Module Zinza.Node Zinza.Parser Zinza.Pos
    Zinza.Type Zinza.Value Zinza.Var Zinza.Writer

import-dirs:          /usr/lib/ghc-9.2.8/site-local/zinza-0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/zinza-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zinza
hs-libraries:         HSzinza-0.2-9jD5lgfRzFzEfxrjlpNboz
depends:
    base-4.16.4.0 containers-0.6.5.1 parsec-3.1.15.0 text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-zinza/html/zinza.haddock
haddock-html:         /usr/share/doc/haskell-zinza/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zinza-0.2-231.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-zinza.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 zinza
version:              0.2
visibility:           public
id:                   zinza-0.2-I9ExfyfCyGkFwynb4boRTt
key:                  zinza-0.2-I9ExfyfCyGkFwynb4boRTt
license:              GPL-2.0-or-later
copyright:            (c) 2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg.Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/zinza
synopsis:             Typed templates with jinja like syntax
description:
    Typed templates with jinja like syntax. Well-typed templates don'\''t go wrong.

category:             Text, Template
abi:                  146af14face43c5f355840cc03e01d17
exposed:              True
exposed-modules:      Zinza
hidden-modules:
    Zinza.Check Zinza.Class Zinza.Errors Zinza.Expr Zinza.Generic
    Zinza.Indexing Zinza.Module Zinza.Node Zinza.Parser Zinza.Pos
    Zinza.Type Zinza.Value Zinza.Var Zinza.Writer

import-dirs:          /usr/lib/ghc-9.4.8/site-local/zinza-0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/zinza-0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/zinza-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zinza
hs-libraries:         HSzinza-0.2-I9ExfyfCyGkFwynb4boRTt
depends:
    base-4.17.2.1 containers-0.6.7 parsec-3.1.16.1 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-zinza/html/zinza.haddock
haddock-html:         /usr/share/doc/haskell-zinza/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
